@@ -433,9 +433,11 @@ __proto__: ModalDialog.ModalDialog.prototype,
 
             if (input.charAt(0) == '/') {
                 path = input;
+            } else {
+                path = GLib.build_filenamev([GLib.get_home_dir(), input]);
             }
 
-            if (GLib.file_test(path, GLib.FileTest.EXISTS)) {
+            if (path && GLib.file_test(path, GLib.FileTest.EXISTS)) {
                 let file = Gio.file_new_for_path(path);
                 try {
                     Gio.app_info_launch_default_for_uri(file.get_uri(),
